pub enum SnapshotIssueSeverity {
Warning,
Error,
}Expand description
Severity assigned to a validation or migration issue.
Variants
Warning
The document is usable, but decoding performed a noteworthy migration.
Error
The document is invalid and cannot be decoded or encoded.